# flake8: noqa
from __future__ import absolute_import, division, print_function

import subprocess
import sys

from tornado5.test.util import unittest

_import_everything = b"""
# The event loop is not fork-safe, and it's easy to initialize an asyncio.Future
# at startup, which in turn creates the default event loop and prevents forking.
# Explicitly disallow the default event loop so that an error will be raised
# if something tries to touch it.
try:
    import asyncio
except ImportError:
    pass
else:
    asyncio.set_event_loop(None)

import tornado5.auth
import tornado5.autoreload
import tornado5.concurrent
import tornado5.escape
import tornado5.gen
import tornado5.http1connection
import tornado5.httpclient
import tornado5.httpserver
import tornado5.httputil
import tornado5.ioloop
import tornado5.iostream
import tornado5.locale
import tornado5.log
import tornado5.netutil
import tornado5.options
import tornado5.process
import tornado5.simple_httpclient
import tornado5.stack_context
import tornado5.tcpserver
import tornado5.tcpclient
import tornado5.template
import tornado5.testing
import tornado5.util
import tornado5.web
import tornado5.websocket
import tornado5.wsgi

try:
    import pycurl
except ImportError:
    pass
else:
    import tornado5.curl_httpclient
"""


class ImportTest(unittest.TestCase):
    def test_import_everything(self):
        # Test that all Tornado modules can be imported without side effects,
        # specifically without initializing the default asyncio event loop.
        # Since we can't tell which modules may have already beein imported
        # in our process, do it in a subprocess for a clean slate.
        proc = subprocess.Popen([sys.executable], stdin=subprocess.PIPE)
        proc.communicate(_import_everything)
        self.assertEqual(proc.returncode, 0)

    def test_import_aliases(self):
        # Ensure we don't delete formerly-documented aliases accidentally.
        import tornado5.ioloop
        import tornado5.gen
        import tornado5.util
        self.assertIs(tornado5.ioloop.TimeoutError, tornado5.util.TimeoutError)
        self.assertIs(tornado5.gen.TimeoutError, tornado5.util.TimeoutError)
